@@ -214,6 +214,14 @@ class IMAPSession(BaseIMAP):
         self.do_expunge = do_expunge
         self.logged_in = False
 
+        # We override the base read so that we only read a certain amount
+        # of data at a time.  OS X and Python has problems with getting 
+        # large amounts of memory at a time, so maybe this will be a way we
+        # can work around that (I don't know, and don't have a mac to test,
+        # but we need to try something).
+        self._read = self.read
+        self.read = self.safe_read
+
     def login(self, username, pwd):
         try:
             BaseIMAP.login(self, username, pwd)  # superclass login
@@ -324,6 +332,21 @@ class IMAPSession(BaseIMAP):
                     return msg
         return None
 
+    # Maximum amount of data that will be read at any one time.
+    MAXIMUM_SAFE_READ = 4096
+    def safe_read(self, size):
+        """Read data from remote, but in manageable sizes."""
+        data = []
+        while size > 0:
+            if size < self.MAXIMUM_SAFE_READ:
+                to_collect = size
+            else:
+                to_collect = self.MAXIMUM_SAFE_READ
+            data.append(self._read(to_collect))
+            size -= self.MAXIMUM_SAFE_READ
+        return "".join(data)
+
+
 class IMAPMessage(message.SBHeaderMessage):
     def __init__(self):
         message.Message.__init__(self)
